@@ -4,23 +4,9 @@
 import json
 from io import StringIO
 
-# 2 vs 3 compatibility
-try:
-    # python 3
-    from urllib.request import HTTPPasswordMgrWithDefaultRealm
-    from urllib.request import HTTPBasicAuthHandler
-    from urllib.request import build_opener
-    from urllib.request import install_opener
-    from urllib.request import Request
-    from urllib.request import urlopen
-except:
-    # python 2
-    from urllib2 import HTTPPasswordMgrWithDefaultRealm
-    from urllib2 import HTTPBasicAuthHandler
-    from urllib2 import build_opener
-    from urllib2 import install_opener
-    from urllib2 import Request
-    from urllib2 import urlopen
+import requests
+from requests.auth import HTTPBasicAuth
+
 
 PLAYER_VIDEO=1
 
@@ -38,7 +24,7 @@ class XBMCJsonTransport(XBMCTransport):
     self.id = 0
 
   def execute(self, method, *args, **kwargs):
-    header = {
+    headers = {
         'Content-Type' : 'application/json',
         'User-Agent' : 'python-xbmc'
         }
@@ -58,20 +44,10 @@ class XBMCJsonTransport(XBMCTransport):
 
     values=json.dumps(params)
     # HTTP Authentication
-    password_mgr = HTTPPasswordMgrWithDefaultRealm()
-    password_mgr.add_password(None, self.url, self.username, self.password)
-    auth_handler = HTTPBasicAuthHandler(password_mgr)
-    opener = build_opener(auth_handler)
-    install_opener(opener)
 
-    data = values
-    req = Request(self.url, data.encode('utf-8'), header)
-    response = urlopen(req)
-    the_page = response.read()
-    if len(the_page) > 0 :
-      return json.load(StringIO(the_page.decode('utf-8')))
-    else:
-      return None # for readability
+    resp = requests.post(self.url, values.encode('utf-8'), headers=headers,auth=(self.username, self.password))
+    resp.raise_for_status()
+    return resp.json()
 
 class XBMC(object):
   """XBMC client"""
